---
Title: KM3NeT server
Author: Jutta
status: review
---

### The KM3NeT Open Data Center

For all data not publishable through the IVOA, the KM3NeT Open Data Centre is serving as interface and/or server to the data. For the setup of this server, the [Django framework](https://www.djangoproject.com/) was used.

#### Implementation

**Software package**

Django is a python-based free and open-source web framework that follows the model-template-views (MTV) architectural pattern. Models implement e.g. the KM3OpenResource description, which serves as basic data description class. Templates allow the display of the information through views, which are accessible via webbrowser. In addition to this, REST API endpoints can be defined to allow managing and querying the data through web requests. It also offers an admin interface which allows manual adaption of the data via the GUI, and media storage which can serve to hold smaller data sets, along with a broad gallery of functions for url handling, testing, model description etc.

**Standards for metadata**

For the django server, which primarily serves as an interface to hold metadata for open science products, the metadata can be freely defined, and will develop with time depending on the requirements of the science communities the data is offered to. At this point, the models used by the server consist of the [following three classes](https://open-data.pages.km3net.de/datamodels/classdefs_overview.html):

* **KM3OpenResource** describes each registered data element, independent of the actual type of data. It holds metadata on the publication, the content and link to a description of the content, various optional identifiers like DOI in addition to the km3net identifier (kid), a link to the storage location of the actual data and metadata on data acess.

* **KM3ResourceCollection** holds and describes links to several KM3OpenResources via their kid, and adds information on the collection. Resources of different kinds can be combined here, indicating e.g. that they belong to the same research object, e.g. the same analysis.

* A **KM3ResourceStream** is used to group resources of the same type in a collection that can be extended by new resources by time. These resources are automatically updated from the defined urls.

#### Data conversion and upload

**Format conversion**
The conversion of the data to be uploaded to the server or simply registered as KM3OpenResource was described in the section on [data sets](https://git.km3net.de/-/ide/project/open-data/openscienceportal/blob/master/-/pages/Dataformats.md#open-data-sets-and-formats). 

**Publication procedure**
The publication procedure involves upload of the data to the server, and adding the resource description to the database. If the data product does not yet have a kid assigned, a kid is added to the resource. With this step, the data is made publicly available.

#### Additional features
The ODC will also be used to store metadata indepent of the publication of the data. It includes e.g. a kid search endpoint to allow to draw the metadata on any digital object registered with the server. This will allow to collect information e.g. on storage location of files and their descriptions. This serves as an interim solution to further the development of e.g. a full workflow management scheme.
