+++
date = "2025-02-11T14:53:59Z"
title = "Get involved in KM3NeT"
type = "article"
draft = false
+++

## Join us for a project

You can join us for student projects or coding challenges and help us improve our data processing and analyses tools!

By working with KM3NeT, you will:

- Work on open-source software used by an international scientific community.
- Gain hands-on experience in scientific computing, data analysis, and machine learning.
- Be mentored by experts in physics, software engineering, and data science.
- Enhance your portfolio and contribute to groundbreaking research.

We welcome students with backgrounds in physics, computer science, engineering, or related fields. Below are some example projects that you could be involved in. For concrete project ideas for the Google Summer of Code, see tables below the areas of software, but feel invited to also make your own project proposals!

### 1. **Machine Learning for Neutrino Event Classification**  
Develop and train machine learning models to distinguish neutrino events from background noise in KM3NeT data.

### 2. **Visualization Tools for Neutrino Events**  
Create interactive 3D visualization tools to represent neutrino interactions and detector responses.

### 3. **Optimizing Monte Carlo Simulations**  
Improve the efficiency of Monte Carlo simulations used for detector performance studies.

| **GSoC idea**                   | Simulation of afterpulses |
|---------------------------------|----------------------------------------------------|
| **Description**                 | The photon detectors (PMTs) of KM3NeT register additional photons due to instrumental effects (after-pulses) which have to be simulated effectively to enhance data quality. In the project, laboratory measurements and data from the detector are used to find an effective way to model this contribution and include them in the low-level detector simulation. |
| **Expected Outcomes**           | after-pulse simulation code |
| **Required Skills**             | C++ or python |
| **Mentor**                      | Computation & Software working group |
| **Project Size & Type**         | Medium (175 hours), medium difficulty. |

### 4. **Data Monitoring and visualization**  
Develop web-based dashboards and monitoring tools for real-time data acquisition and analysis.

### 5. **Extending KM3NeT System and Software Documentation**  
Improve the documentation of KM3NeT’s software frameworks to make it more accessible for new contributors.

| **GSoC idea**                   | KM3NeT software and systems monitoring |
|---------------------------------|----------------------------------------------------|
| **Description**                 | KM3NeT operates diverse systems and manages a large set of different software tools. Create an effective way to describe and monitor software developments and system availabilities by integrating already existing tools. The technical approach to this task can be chosen freely. |
| **Expected Outcomes**           | system model, monitoring interface, unified access to software documentation. |
| **Required Skills**             | software management, SysML |
| **Mentor**                      | J. Schnabel, FAU Erlangen, Germany |
| **Project Size & Type**         | Medium (175 hours) or Large (350 hours) possible, medium to high difficulty. |


### 5. **Creating LLM-based interface tools for KM3NeT**  
Use the power of large-language-models to build interoperable scientific workflows.

| **GSoC idea**                   | LLM client for KM3NeT open data products |
|---------------------------------|----------------------------------------------------|
| **Description**                 | Based on the [LLMTuner package](https://git.km3net.de/jschnabel/llmtuner), create a RAG-enhanced chat client for the KM3NeT open data products, and provide a python API for integration of the chat in scientific workflows. Define quality parameters for the chat client performance. Can be extended to include additional finetuning or tools application in the chat client development. |
| **Expected Outcomes**           | RAG-enhanced chat interface, integration into KM3NeT analysis framework.  |
| **Required Skills**             | Python, LLMs |
| **Mentor**                      | J. Schnabel, FAU Erlangen, Germany |
| **Project Size & Type**         | Medium (175 hours) or Large (350) possible, medium difficulty. |

## Get in Touch
If you have any questions or want to discuss your project ideas, feel free to contact us at [opendata@km3net.de](mailto:opendata@km3net.de). We also encourage you to explore our Software or follow us on social media:

@km3net at [X](https://x.com/km3net), [Facebook](https://www.facebook.com/KM3NeT), [Instagram](https://www.instagram.com/km3net) and [Bluesky](https://bsky.app/profile/km3net.bsky.social)

YouTube channel: [KM3NeTneutrino](https://m.youtube.com/user/KM3NeTneutrino/playlists)


## Join KM3NeT as a member

If you are a scientist interested in becoming a KM3NeT member, you can find more information on our website [km3net.org](https://www.km3net.org/about-km3net/collaboration/join-km3net/)